
# gh-auto

`gh-auto` is a cli-tool by developers for developers. It will speed up your github workflow! This, by not only managing your online repo's, but also managing your local repositories!

[![GitHub issues](https://img.shields.io/github/issues-raw/JefvdA/gh-auto)](https://github.com/JefvdA/gh-auto/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed-raw/JefvdA/gh-auto)](https://github.com/JefvdA/gh-auto/issues?q=is%3Aissue+is%3Aclosed)
[![GitHub contributors](https://img.shields.io/github/contributors-anon/JefvdA/gh-auto)](https://github.com/JefvdA/gh-auto/graphs/contributors)
[![GitHub release (latest by date)](https://img.shields.io/github/v/release/JefvdA/gh-auto)](https://github.com/JefvdA/gh-auto/releases)
[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://github.com/JefvdA/gh-auto/blob/main/LICENCE.md)
## Installation

Install gh-auto with PyPi

```
Coming soon!
```
    
## Authentication

gh-auto works with github, so naturally, you need to authenticate with github aswell.
Checkout the [github documentation](https://docs.github.com/en/authentication/keeping-your-account-and-data-secure/creating-a-personal-access-token) if you don't know how to do this.

When using gh-auto for the first time, you will be asked for your authentication token. The token will then be  stored locally for futrure use.
## Authors - LinkedIn

- [@JefvdA](https://www.linkedin.com/in/jefvda/)


## Roadmap 

If you want to view the roadmap of this project, take a look at our [github project](https://github.com/users/JefvdA/projects/1)

## License

[MIT](https://github.com/JefvdA/gh-auto/blob/main/LICENCE.md)
